Code39Decoder class
Code 39 barcode decoder.
Code 39 is a variable length, discrete barcode symbology. Each character is represented by 9 bars/spaces: 5 bars and 4 spaces. 3 of these 9 elements are wide (hence "Code 39" = 3 of 9).
Supported characters: 0-9, A-Z, -, ., $, /, +, %, space Start/Stop character: * (asterisk)
- Inheritance
-
- Object
- BarcodeDecoder
- Code39Decoder
Constructors
- Code39Decoder({bool checkDigit = false})
-
const
Properties
- checkDigit → bool
-
If true, validates and strips Modulo 43 check digit.
final
- format → String
-
The format name of this decoder (e.g., 'EAN_13', 'CODE_128').
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
BitMatrix matrix) → BarcodeResult? -
Scans the bit matrix to find and decode a barcode.
inherited
-
decodeRow(
{required int rowNumber, required int width, required Uint16List runs, Uint8List? row}) → BarcodeResult? -
Attempts to decode a barcode from a single row of the bit matrix.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
validateMod43(
String text) → bool - Validates Modulo 43 check digit. This is optional for Code 39 but recommended for high reliability.